@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 
 __author__ = "Vanessa Sochat"
-__copyright__ = "Copyright 2021-2022, Vanessa Sochat"
+__copyright__ = "Copyright 2021-2023, Vanessa Sochat"
 __license__ = "MPL 2.0"
 
 import argparse
@@ -239,7 +239,7 @@ shpc view edit <name>""",
 shpc config set key value
 shpc config set key:subkey value
 shpc config get key
-shpc edit
+shpc config edit
 shpc config inituser
 shpc config add registry /tmp/registry
 shpc config remove registry /tmp/registry""",
@@ -310,7 +310,15 @@ shpc config remove registry /tmp/registry""",
         action="store_true",
     )
     uninstall.add_argument(
-        "uninstall_recipe", help="module to uninstall (module/version)"
+        "uninstall_recipe", help="module to uninstall (module/version)", nargs="?"
+    )
+    uninstall.add_argument(
+        "--all",
+        "-a",
+        dest="uninstall_all",
+        help="uninstall all recipes",
+        default=False,
+        action="store_true",
     )
 
     # Update gets latest tags from OCI registries
